# Keygener a easy to use password or key generater

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)

## Functionality of Keygener

- Generate unique Keys
- Generate unique Passwords
- Pick Random Number from a list of numbers

## Usage

- Make sure you have Python installed in your system.
- Run Following command in the CMD.
 ```
  pip install Keygener
  ```
# Keygener has 3 functions that you can use 
- 1. genKey(length of the key you need to generate) 
- 2. genPass(length of the Password you need to generate)
- 3. pickRan(list('12345678'),How much values you need to pick)
## Example
 ```
# genKey()
import keygener
keygener.genKey(10)
- Out put
XV6gmjB5CV
 ```
# genPass()
import keygener
keygener.genPass(20)
- Out put
±j/U?f,I4hv%L{V7§^ez
 ```
# pickRan()
import keygener
keygener.pickRan(list('1234567890',2)
- Out put
26
 ```

